@@ -47,7 +47,7 @@ public:
     Plugin_Imageshack(QObject* const parent, const QVariantList& args);
     ~Plugin_Imageshack();
 
-    void setup(QWidget* const) Q_DECL_OVERRIDE;
+    void setup(QWidget* const) override;
 
 public Q_SLOTS:
 
